@@ -13,5 +13,11 @@ Build HTML from the generated ReST files using Sphinx.
 Sphinx has to be installed for this to work.
 """
 cli_option_css_help = """\b
-Include the custom CSS from the EPUB for the HTML output
+Include the custom CSS and Fonts from the EPUB for the HTML output
 """
+cli_option_overwrite_help = """\b
+Overwrite the output directory if present already
+"""
+cli_option_port_help = """\b
+The port number on which the files will be served after conversion
+"""
\ No newline at end of file
